// HorizontalLayoutManager.cpp
// Copyright(C) 1999 by Kiyoshi Kobayashi. All rights reserved.
//

#include <Debug.h>
#include <SupportDefs.h>

#include "HorizontalLayoutManager.h"

static const BRect allZero(0.0f, 0.0f, 0.0f, 0.0f);

void
HorizontalLayoutManager::doSetLimits(const BRect &newMin, const BRect &newMax) {
	// Here is the logic for the horizontal layout!
	// Minimum limit
	BRect &curMin = GetMin();
	if (curMin == allZero)
		curMin = newMin;
	else {
		float minr = curMin.right + newMin.Width();
		float minb = max_c(curMin.bottom, newMin.bottom);
		curMin.SetRightBottom(BPoint(minr, minb));
	}
	
	// Maximum limit
	BRect &curMax = GetMax();
	if (curMax == allZero)
		curMax = newMax;
	else {
		float maxr = curMax.right + newMax.Width();
		float maxb = min_c(curMax.bottom, newMax.bottom);
		curMax.SetRightBottom(BPoint(maxr, maxb));
	}	
	PRINT_OBJECT(GetMin());
	PRINT_OBJECT(GetMax());
}

void
HorizontalLayoutManager::doLayout() {
	TRACE();
	BRect f = GetBaseView()->Bounds();

	const float w = f.Width() / (GetBaseView()->CountChildren() - 0);
	
	BRect tmp(f.left, f.top, f.left + w, f.bottom);
	
	BView *child = GetBaseView()->ChildAt(0);
	while ( child ) {
		if (tmp != child->Frame()) {
			child->MoveTo(tmp.LeftTop());
			child->ResizeTo(tmp.Width(), tmp.Height());
		}

		tmp.OffsetTo(tmp.RightTop());
		
		child = child->NextSibling();
	}

}
