// LayoutManager.cpp
// Copyright(C) 1999 by Kiyoshi Kobayashi. All rights reserved.
//

#include <Debug.h>
#include <Window.h>

#include "LayoutManager.h"
#include "HorizontalLayoutManager.h"
#include "VerticalLayoutManager.h"

void
LayoutManager::SetLimits() {
	min.Set(0.0f, 0.0f, 0.0f, 0.0f);
	max.Set(0.0f, 0.0f, 0.0f, 0.0f);

	BaseView *base = NULL;
	BView *child = view->ChildAt(0);
	while (child != NULL) {
		if (is_kind_of(child, BaseView)) {
			base = cast_as(child, BaseView);
			
			BRect tmpMin = base->GetMinSize();
			BRect tmpMax = base->GetMaxSize();

			doSetLimits(tmpMin, tmpMax);
		

		}
		child = child->NextSibling();
	}
	
	view->SetMinSize(min);
	view->SetMaxSize(max);
	
	if ((view->Parent()) == NULL) // assume it's running as app
		view->Window()->SetSizeLimits(min.Width(), max.Width(),
									  min.Height(), max.Height());
}
	
void
LayoutManager::Layout() {
	BaseView *view = GetBaseView();

	// Adjust the size of the view
	const float w = view->Bounds().Width();
	const float h = view->Bounds().Height();
	const float minw = view->GetMinSize().Width();
	const float maxw = view->GetMaxSize().Width();
	const float minh = view->GetMinSize().Height();
	const float maxh = view->GetMaxSize().Height();

	float wd = w, hd = h;
	
	// Limit the width
	if (w < minw)
		wd = minw;
	if (w > maxw)
		wd = maxw;
	
	// Limit the height
	if (h < minh)
		hd = minh;
	if (h > maxh)
		hd = maxh;
	
	// Resize if it's needed
	if ((wd != w) || (hd != h)) {
		if (view->Parent() == NULL) // assume it's running as BeYap app
			view->Window()->ResizeTo(wd, hd);
		else
			view->ResizeTo(wd, hd);
	}
	doLayout();
}

// static factory method
LayoutManager *
LayoutManager::CreateLayoutManager(LayoutType layoutType,
								   BaseView *baseView) {
	LayoutManager *ret = NULL;
	switch(layoutType) {
		case	LT_VERTICAL:
			ret = new VerticalLayoutManager(baseView);
			break;
		case	LT_HORIZONTAL:
			ret = new HorizontalLayoutManager(baseView);
			break;
		default:
			ret = NULL;
			break;
	}
	return ret;
}
