// VerticalLayoutManager.cpp
// Copyright(C) 1999 by Kiyoshi Kobayashi. All rights reserved.
//

#include <Debug.h>
#include <SupportDefs.h>

#include "VerticalLayoutManager.h"

static const BRect allZero(0.0f, 0.0f, 0.0f, 0.0f);

void
VerticalLayoutManager::doSetLimits(const BRect &newMin, const BRect &newMax) {
	// Here is the logic for the vertical layout!
	// Minimum limits
	BRect &curMin = GetMin();
	if (curMin == allZero)
		curMin = newMin;
	else {
		float minr = max_c(curMin.right, newMin.right);
		float minb = curMin.bottom + newMin.Height();
		curMin.SetRightBottom(BPoint(minr, minb));
	}
	
	// Maximum limits
	BRect &curMax = GetMax();
	if (curMax == allZero)
		curMax = newMax;
	else {
		float maxr = min_c(curMax.right, newMax.right);
		float maxb = curMax.bottom + newMax.Height();
		curMax.SetRightBottom(BPoint(maxr, maxb));
	}
}

void
VerticalLayoutManager::doLayout() {
	TRACE();
	BRect f = GetBaseView()->Bounds();
	
	const float h = f.Height() / (GetBaseView()->CountChildren() - 0);
	BRect tmp(f.left, f.top, f.right, f.top + h);
	
	BView *child = GetBaseView()->ChildAt(0);
	while ( child ) {
		if (tmp != child->Frame()) {
			child->MoveTo(tmp.LeftTop());
			child->ResizeTo(tmp.Width(), tmp.Height());
		}
		tmp.OffsetTo(child->Frame().LeftBottom());
		
		child = child->NextSibling();
	}
}

