// SysInfo.h
// Copyright(C) 1999 by Kiyoshi Kobayashi. All rights reserved.
//
//
#ifndef _SYS_INFO_H_
#define _SYS_INFO_H_

#include <OS.h>
#include <stdio.h>
#include <string.h>

// This class encasulates the system information.
//
class SysInfo {
public:
	SysInfo() {
		get_system_info(&info);
		time = system_time();
		
		#ifdef DEBUG_CPU
		int tmp = info.cpu_count;
		info.cpu_count = DEBUG_CPU;
		for (int i = tmp; i < info.cpu_count; i++)
			info.cpu_infos[i].active_time
				= info.cpu_infos[0].active_time;
		#endif
	};

	SysInfo(const SysInfo &src)
		: time(src.time), info(src.info) {};

	~SysInfo() {
		time = 0;
	};
	
	inline
	bigtime_t GetSystemTime() const { return time; };
	inline
	const system_info &GetInfo() const { return info; };
	inline
	void PrintToStream() const { printf("SysInfo:\n"); };
	
	inline
	SysInfo operator =(const SysInfo &src) {
		this->time = src.time;
		this->info.id[0] = src.info.id[0];
		this->info.id[1] = src.info.id[1];
		this->info.boot_time = src.info.boot_time;
		this->info.cpu_count = src.info.cpu_count;
		this->info.cpu_type = src.info.cpu_type;
		this->info.cpu_revision = src.info.cpu_revision;
		this->info.cpu_clock_speed = src.info.cpu_clock_speed;
		this->info.bus_clock_speed = src.info.bus_clock_speed;
		this->info.platform_type = src.info.platform_type;
		this->info.max_pages = src.info.max_pages;
		this->info.used_pages = src.info.used_pages;
		this->info.page_faults = src.info.page_faults;
		this->info.max_sems = src.info.max_sems;
		this->info.used_sems = src.info.used_sems;
		this->info.max_ports = src.info.max_ports;
		this->info.used_ports = src.info.used_ports;
		this->info.max_threads = src.info.max_threads;
		this->info.used_threads = src.info.used_threads;
		this->info.max_teams = src.info.max_teams;
		this->info.used_teams = src.info.used_teams;
		this->info.kernel_version = src.info.kernel_version;
		this->info.kernel_name[0] = '\0';
		strcpy(this->info.kernel_name, src.info.kernel_name);
		this->info.kernel_build_date[0] = '\0';
		strcpy(this->info.kernel_build_date, src.info.kernel_build_date);
		this->info.kernel_build_time[0] = '\0';
		strcpy(this->info.kernel_build_time, src.info.kernel_build_time);
		for (int i = 0; i < B_MAX_CPU_COUNT; i++)
			this->info.cpu_infos[i].active_time
				= src.info.cpu_infos[i].active_time;
		return *this;
	};

	inline
	friend SysInfo operator -(const SysInfo &left,
								const SysInfo &right);
  private:
    char  kernel_name[B_FILE_NAME_LENGTH];  
    char  kernel_build_date[B_OS_NAME_LENGTH]; 
    char  kernel_build_time[B_OS_NAME_LENGTH]; 

	bigtime_t time;
	system_info info;
};

inline SysInfo
operator -(const SysInfo &left, const SysInfo &right) {
	SysInfo ret(left);
	ret.time -= right.time;
	ret.info.used_pages = right.info.used_pages;
	ret.info.page_faults -= right.info.page_faults;
	ret.info.used_sems -= right.info.used_sems;
	ret.info.used_ports -= right.info.used_ports;
	ret.info.used_threads -= right.info.used_threads;
	ret.info.used_teams -= right.info.used_teams;
	for (int i = 0; i < B_MAX_CPU_COUNT; i++) {
		ret.info.cpu_infos[i].active_time
			-= right.info.cpu_infos[i].active_time;
	}
	return ret;
};
	
#endif /* _SYS_INFO_H_ */
